# CC 410 Restaurant Register

[![License](https://img.shields.io/github/license/russfeld/restaurantregister-python)](https://github.com/russfeld/restaurantregister-python/blob/main/LICENSE)
[![Latest Release](https://img.shields.io/github/v/release/russfeld/restaurantregister-python)](https://github.com/russfeld/restaurantregister-python/releases)
[![Build](https://github.com/russfeld/restaurantregister-python/actions/workflows/build-python.yml/badge.svg)](https://github.com/russfeld/restaurantregister-python/actions/workflows/build-python.yml)
[![GitHub deployments](https://img.shields.io/github/deployments/russfeld/restaurantregister-python/github-pages?label=docs)](https://russfeld.github.io/restaurantregister-python/)
![Coverage](https://raw.githubusercontent.com/russfeld/restaurantregister-python/badges/.badges/main/coverage.svg)

This library is intended for use in CC 410 course at Kansas State University

[Documentation](https://russfeld.github.io/restaurantregister-python/)

For more information, see the [CC program website](http://www.cs.ksu.edu/core/)

